<template>
  <div class="InfoPopup">
    <Popup
      ref="pop"
      v-for="(data, index) in PopupData"
      :key="data.id"
      :title="data.title || '提示'"
      :maxHeight="data.maxHeight || '500px'"
      @close="close(data.id)"
      :left="data.left || left"
      :top="data.top || top + index * 42 + 'px'"
    >
      <div class="InfoPopupContianer">
        <div v-html="data.value"></div>
      </div>
    </Popup>
  </div>
</template>

<script>
import Popup from "@tools/Popup";
export default {
  name: "mapinfo",
  components: {
    Popup,
  },
  data() {
    return {
      // 弹窗数据
      PopupData: [],
      left: "calc(100% - 330px)",
      top: 10,
    };
  },
  computed: {},
  mounted() {},
  methods: {
    // 关闭所有
    closeAll() {
      this.PopupData.forEach((item) => {
        item.close && item.close();
      });
      this.PopupData = [];
    },
    // 关闭弹窗
    close(id) {
      let index = this.PopupData.findIndex((item) => {
        return item.id === id;
      });
      let data = this.PopupData.splice(index, 1)[0];
      data.close && data.close();
    },
    // 打开弹窗
    open(title, value, style = {}) {
      this.PopupData.push({
        id: this.createRandomId(),
        title,
        value,
        ...style,
      });
      let index = this.PopupData.length - 1;
      this.$nextTick(() => {
        this.$refs.pop[index].open();
      });
      return this.PopupData[index];
    },
    // 随机id
    createRandomId() {
      return (
        (Math.random() * 10000000).toString(16).substr(0, 4) +
        "-" +
        new Date().getTime() +
        "-" +
        Math.random().toString().substr(2, 5)
      );
    },
  },
};
</script>

<style scoped lang="less">
.text {
  margin-left: 15px;
  margin-right: 15px;
}
</style>
